@@ -9,11 +9,11 @@
 #include "ColorSchemeViewDelegate.h"
 
 // Konsole
+#include "../config-konsole.h"
 #include "ColorScheme.h"
 
 // KDE
 #include <KLocalizedString>
-#include <KWindowSystem>
 
 // Qt
 #include <QApplication>
@@ -21,9 +21,11 @@
 
 using namespace Konsole;
 
-ColorSchemeViewDelegate::ColorSchemeViewDelegate(QObject *parent)
+ColorSchemeViewDelegate::ColorSchemeViewDelegate(std::function<bool()> compositingActiveHelper, QObject *parent)
     : QAbstractItemDelegate(parent)
+    , m_compositingActive(std::move(compositingActiveHelper))
 {
+    Q_ASSERT(m_compositingActive);
 }
 
 void ColorSchemeViewDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const
@@ -59,9 +61,7 @@ void ColorSchemeViewDelegate::paint(QPainter *painter, const QStyleOptionViewIte
 
     QRect previewRect(x + 4, y + 4, sampleTextWidth + 8, option.rect.height() - 8);
 
-    bool transparencyAvailable = KWindowSystem::compositingActive();
-
-    if (transparencyAvailable) {
+    if (m_compositingActive()) {
         painter->save();
         QColor color = scheme->backgroundColor();
         color.setAlphaF(scheme->opacity());
@@ -95,3 +95,5 @@ QSize ColorSchemeViewDelegate::sizeHint(const QStyleOptionViewItem &option, cons
     // temporary
     return {width, heightForWidth};
 }
+
+#include "moc_ColorSchemeViewDelegate.cpp"
